#include "G4TubeMat.hh"
#include "G4MacroMenu.hh"
#include <TString.h>
#include <stdlib.h>
#include <TGLabel.h>
#include "TGTextEntry.h"
#include "TGTextView.h"
#include <stdio.h>
#include <iostream>
#include <fstream>
#include <string.h>
#include <TSystem.h>
#include <cmath>

using namespace std;
using std::string;

enum AliEnergyMessageTypes {
  kM_OK_TUBEMAT,
  kM_CLEARALL_TUBEMAT,
  kM_EXIT_TUBEMAT
};

const Double_t A_O   = 15.9994;
const Double_t A_H   = 1.00794;
const Double_t A_Al  = 26.981538;
const Double_t A_Si  = 28.0855;
const Double_t A_Mg  = 24.3050;
const Double_t A_P   = 30.973761;
const Double_t A_Ti  = 47.867;
const Double_t A_K   = 39.0983;
const Double_t A_Na  = 22.989770;
const Double_t A_Ca  = 40.078;
const Double_t A_Mn  = 54.938049;
const Double_t A_Fe  = 55.845;

G4TubeMat::G4TubeMat(G4MacroMenu* cm, const TGWindow *p, const TGWindow *main, UInt_t w, UInt_t h, UInt_t options) : TGTransientFrame(p, main, w, h, options),tmmacroMenu(cm)
{

  fLTubeMatFM1Frame = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatFM1Frame = BuildTubeMatFM1Frame(this);
  AddFrame(fTubeMatFM1Frame, fLTubeMatFM1Frame);

  fLTubeMatFM2Frame = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatFM2Frame = BuildTubeMatFM2Frame(this);
  AddFrame(fTubeMatFM2Frame, fLTubeMatFM2Frame);

  fLTubeMatFM3Frame = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatFM3Frame = BuildTubeMatFM3Frame(this);
  AddFrame(fTubeMatFM3Frame, fLTubeMatFM3Frame);

  fLTubeMatFM4Frame = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatFM4Frame = BuildTubeMatFM4Frame(this);
  AddFrame(fTubeMatFM4Frame, fLTubeMatFM4Frame);

  fLTubeMatFM5Frame = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatFM5Frame = BuildTubeMatFM5Frame(this);
  AddFrame(fTubeMatFM5Frame, fLTubeMatFM5Frame);

  fLTubeMatFM6Frame = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatFM6Frame = BuildTubeMatFM6Frame(this);
  AddFrame(fTubeMatFM6Frame, fLTubeMatFM6Frame);

  fLTubeMatFM7Frame = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatFM7Frame = BuildTubeMatFM7Frame(this);
  AddFrame(fTubeMatFM7Frame, fLTubeMatFM7Frame);

  fLTubeMatInputName = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputNameFrame = BuildTubeMatInputNameEntry(fTubeMatFM1Frame);
  fTubeMatFM1Frame->AddFrame(fTubeMatInputNameFrame, fLTubeMatInputName);

  fLTubeMatInputNameDef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputNameDefFrame = BuildTubeMatInputNameDefEntry(fTubeMatFM1Frame);
  fTubeMatFM1Frame->AddFrame(fTubeMatInputNameDefFrame, fLTubeMatInputNameDef);

  fLTubeMatInputDensity = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputDensityFrame = BuildTubeMatInputDensityEntry(fTubeMatFM1Frame);
  fTubeMatFM1Frame->AddFrame(fTubeMatInputDensityFrame, fLTubeMatInputDensity);

  fLTubeMatInputDensityDef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputDensityDefFrame = BuildTubeMatInputDensityDefEntry(fTubeMatFM1Frame);
  fTubeMatFM1Frame->AddFrame(fTubeMatInputDensityDefFrame, fLTubeMatInputDensityDef);

  fLTubeMatInputSiO2 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputSiO2Frame = BuildTubeMatInputSiO2Entry(fTubeMatFM2Frame);
  fTubeMatFM2Frame->AddFrame(fTubeMatInputSiO2Frame, fLTubeMatInputSiO2);

  fLTubeMatInputSiO2Def = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputSiO2DefFrame = BuildTubeMatInputSiO2DefEntry(fTubeMatFM2Frame);
  fTubeMatFM2Frame->AddFrame(fTubeMatInputSiO2DefFrame, fLTubeMatInputSiO2Def);

  fLTubeMatInputAl2O3 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputAl2O3Frame = BuildTubeMatInputAl2O3Entry(fTubeMatFM2Frame);
  fTubeMatFM2Frame->AddFrame(fTubeMatInputAl2O3Frame, fLTubeMatInputAl2O3); 

  fLTubeMatInputAl2O3Def = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputAl2O3DefFrame = BuildTubeMatInputAl2O3DefEntry(fTubeMatFM2Frame);
  fTubeMatFM2Frame->AddFrame(fTubeMatInputAl2O3DefFrame, fLTubeMatInputAl2O3Def);

  fLTubeMatInputFe2O3 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputFe2O3Frame = BuildTubeMatInputFe2O3Entry(fTubeMatFM3Frame);
  fTubeMatFM3Frame->AddFrame(fTubeMatInputFe2O3Frame, fLTubeMatInputFe2O3); 

  fLTubeMatInputFe2O3Def = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputFe2O3DefFrame = BuildTubeMatInputFe2O3DefEntry(fTubeMatFM3Frame);
  fTubeMatFM3Frame->AddFrame(fTubeMatInputFe2O3DefFrame, fLTubeMatInputFe2O3Def);

  fLTubeMatInputFeO = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputFeOFrame = BuildTubeMatInputFeOEntry(fTubeMatFM3Frame);
  fTubeMatFM3Frame->AddFrame(fTubeMatInputFeOFrame, fLTubeMatInputFeO); 

  fLTubeMatInputFeODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputFeODefFrame = BuildTubeMatInputFeODefEntry(fTubeMatFM3Frame);
  fTubeMatFM3Frame->AddFrame(fTubeMatInputFeODefFrame, fLTubeMatInputFeODef);

  fLTubeMatInputMgO = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputMgOFrame = BuildTubeMatInputMgOEntry(fTubeMatFM4Frame);
  fTubeMatFM4Frame->AddFrame(fTubeMatInputMgOFrame, fLTubeMatInputMgO); 

  fLTubeMatInputMgODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputMgODefFrame = BuildTubeMatInputMgODefEntry(fTubeMatFM4Frame);
  fTubeMatFM4Frame->AddFrame(fTubeMatInputMgODefFrame, fLTubeMatInputMgODef);

  fLTubeMatInputCaO = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputCaOFrame = BuildTubeMatInputCaOEntry(fTubeMatFM4Frame);
  fTubeMatFM4Frame->AddFrame(fTubeMatInputCaOFrame, fLTubeMatInputCaO); 

  fLTubeMatInputCaODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputCaODefFrame = BuildTubeMatInputCaODefEntry(fTubeMatFM4Frame);
  fTubeMatFM4Frame->AddFrame(fTubeMatInputCaODefFrame, fLTubeMatInputCaODef);

  fLTubeMatInputNa2O = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputNa2OFrame = BuildTubeMatInputNa2OEntry(fTubeMatFM5Frame);
  fTubeMatFM5Frame->AddFrame(fTubeMatInputNa2OFrame, fLTubeMatInputNa2O); 

  fLTubeMatInputNa2ODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputNa2ODefFrame = BuildTubeMatInputNa2ODefEntry(fTubeMatFM5Frame);
  fTubeMatFM5Frame->AddFrame(fTubeMatInputNa2ODefFrame, fLTubeMatInputNa2ODef);

  fLTubeMatInputK2O = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputK2OFrame = BuildTubeMatInputK2OEntry(fTubeMatFM5Frame);
  fTubeMatFM5Frame->AddFrame(fTubeMatInputK2OFrame, fLTubeMatInputK2O); 

  fLTubeMatInputK2ODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputK2ODefFrame = BuildTubeMatInputK2ODefEntry(fTubeMatFM5Frame);
  fTubeMatFM5Frame->AddFrame(fTubeMatInputK2ODefFrame, fLTubeMatInputK2ODef);

  fLTubeMatInputTiO2 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputTiO2Frame = BuildTubeMatInputTiO2Entry(fTubeMatFM6Frame);
  fTubeMatFM6Frame->AddFrame(fTubeMatInputTiO2Frame, fLTubeMatInputTiO2); 

  fLTubeMatInputTiO2Def = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputTiO2DefFrame = BuildTubeMatInputTiO2DefEntry(fTubeMatFM6Frame);
  fTubeMatFM6Frame->AddFrame(fTubeMatInputTiO2DefFrame, fLTubeMatInputTiO2Def);

  fLTubeMatInputP2O5 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputP2O5Frame = BuildTubeMatInputP2O5Entry(fTubeMatFM6Frame);
  fTubeMatFM6Frame->AddFrame(fTubeMatInputP2O5Frame, fLTubeMatInputP2O5); 

  fLTubeMatInputP2O5Def = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputP2O5DefFrame = BuildTubeMatInputP2O5DefEntry(fTubeMatFM6Frame);
  fTubeMatFM6Frame->AddFrame(fTubeMatInputP2O5DefFrame, fLTubeMatInputP2O5Def);

  fLTubeMatInputMnO = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputMnOFrame = BuildTubeMatInputMnOEntry(fTubeMatFM7Frame);
  fTubeMatFM7Frame->AddFrame(fTubeMatInputMnOFrame, fLTubeMatInputMnO); 

  fLTubeMatInputMnODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputMnODefFrame = BuildTubeMatInputMnODefEntry(fTubeMatFM7Frame);
  fTubeMatFM7Frame->AddFrame(fTubeMatInputMnODefFrame, fLTubeMatInputMnODef);

  fLTubeMatInputH2O = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputH2OFrame = BuildTubeMatInputH2OEntry(fTubeMatFM7Frame);
  fTubeMatFM7Frame->AddFrame(fTubeMatInputH2OFrame, fLTubeMatInputH2O); 

  fLTubeMatInputH2ODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsTop, 10, 10, 10, 10);
  fTubeMatInputH2ODefFrame = BuildTubeMatInputH2ODefEntry(fTubeMatFM7Frame);
  fTubeMatFM7Frame->AddFrame(fTubeMatInputH2ODefFrame, fLTubeMatInputH2ODef);

 fLTubeMatButtonFrame = new TGLayoutHints(kLHintsCenterX | kLHintsBottom,0, 0, 0, 0);
  fTubeMatButtonFrame = BuildTubeMatButtonFrame(this);
  AddFrame(fTubeMatButtonFrame, fLTubeMatButtonFrame);


MapSubwindows();

SetWindowName("Tube : creation du materiau composant l'echantillon");

Layout();


MapWindow();

}


G4TubeMat::~G4TubeMat() 
{


  //boutons
 if (fOkTubeMatButton)
   delete fOkTubeMatButton;
 if (fClearAllTubeMatButton)
   delete fClearAllTubeMatButton;
 if (fExitTubeMatButton)
   delete fExitTubeMatButton;

 //lignes de texte pour entrer les variables
 if (fInputTubeMatNameEntry)
   delete fInputTubeMatNameEntry;
 if (fInputTubeMatNameDefEntry)
   delete fInputTubeMatNameDefEntry;
 if (fInputTubeMatDensityEntry)
   delete fInputTubeMatDensityEntry;
 if (fInputTubeMatDensityDefEntry)
   delete fInputTubeMatDensityDefEntry;
 if (fInputTubeMatSiO2Entry)
   delete fInputTubeMatSiO2Entry;
 if (fInputTubeMatSiO2DefEntry)
   delete fInputTubeMatSiO2DefEntry;
 if (fInputTubeMatAl2O3Entry)
   delete fInputTubeMatAl2O3Entry;
 if (fInputTubeMatAl2O3DefEntry)
   delete fInputTubeMatAl2O3DefEntry;
 if (fInputTubeMatFe2O3Entry)
   delete fInputTubeMatFe2O3Entry;
 if (fInputTubeMatFe2O3DefEntry)
   delete fInputTubeMatFe2O3DefEntry;
 if (fInputTubeMatFeOEntry)
   delete fInputTubeMatFeOEntry;
 if (fInputTubeMatFeODefEntry)
   delete fInputTubeMatFeODefEntry;
 if (fInputTubeMatMgOEntry)
   delete fInputTubeMatMgOEntry;
 if (fInputTubeMatMgODefEntry)
   delete fInputTubeMatMgODefEntry;
 if (fInputTubeMatCaOEntry)
   delete fInputTubeMatCaOEntry;
 if (fInputTubeMatCaODefEntry)
   delete fInputTubeMatCaODefEntry;
 if (fInputTubeMatNa2OEntry)
   delete fInputTubeMatNa2OEntry;
 if (fInputTubeMatNa2ODefEntry)
   delete fInputTubeMatNa2ODefEntry;
 if (fInputTubeMatK2OEntry)
   delete fInputTubeMatK2OEntry;
 if (fInputTubeMatK2ODefEntry)
   delete fInputTubeMatK2ODefEntry;
 if (fInputTubeMatTiO2Entry)
   delete fInputTubeMatTiO2Entry;
 if (fInputTubeMatTiO2DefEntry)
   delete fInputTubeMatTiO2DefEntry;
 if (fInputTubeMatP2O5Entry)
   delete fInputTubeMatP2O5Entry;
 if (fInputTubeMatP2O5DefEntry)
   delete fInputTubeMatP2O5DefEntry;
 if (fInputTubeMatMnOEntry)
   delete fInputTubeMatMnOEntry;
 if (fInputTubeMatMnODefEntry)
   delete fInputTubeMatMnODefEntry;
 if (fInputTubeMatH2OEntry)
   delete fInputTubeMatH2OEntry;
 if (fInputTubeMatH2ODefEntry)
   delete fInputTubeMatH2ODefEntry;


 //labels
 if (fInputTubeMatNameLabel)
   delete fInputTubeMatNameLabel;
 if (fInputTubeMatNameDefLabel)
   delete fInputTubeMatNameDefLabel;
 if (fInputTubeMatDensityLabel)
   delete fInputTubeMatDensityLabel;
 if (fInputTubeMatDensityDefLabel)
   delete fInputTubeMatDensityDefLabel;
 if (fInputTubeMatSiO2Label)
   delete fInputTubeMatSiO2Label;
 if (fInputTubeMatSiO2DefLabel)
   delete fInputTubeMatSiO2DefLabel;
 if (fInputTubeMatAl2O3Label)
   delete fInputTubeMatAl2O3Label;
 if (fInputTubeMatAl2O3DefLabel)
   delete fInputTubeMatAl2O3DefLabel;
 if (fInputTubeMatFe2O3Label)
   delete fInputTubeMatFe2O3Label;
 if (fInputTubeMatFe2O3DefLabel)
   delete fInputTubeMatFe2O3DefLabel;
 if (fInputTubeMatFeOLabel)
   delete fInputTubeMatFeOLabel;
 if (fInputTubeMatFeODefLabel)
   delete fInputTubeMatFeODefLabel;
 if (fInputTubeMatMgOLabel)
   delete fInputTubeMatMgOLabel;
 if (fInputTubeMatMgODefLabel)
   delete fInputTubeMatMgODefLabel;
 if (fInputTubeMatCaOLabel)
   delete fInputTubeMatCaOLabel;
 if (fInputTubeMatCaODefLabel)
   delete fInputTubeMatCaODefLabel;
 if (fInputTubeMatNa2OLabel)
   delete fInputTubeMatNa2OLabel;
 if (fInputTubeMatNa2ODefLabel)
   delete fInputTubeMatNa2ODefLabel;
 if (fInputTubeMatK2OLabel)
   delete fInputTubeMatK2OLabel;
 if (fInputTubeMatK2ODefLabel)
   delete fInputTubeMatK2ODefLabel;
 if (fInputTubeMatTiO2Label)
   delete fInputTubeMatTiO2Label;
 if (fInputTubeMatTiO2DefLabel)
   delete fInputTubeMatTiO2DefLabel;
 if (fInputTubeMatP2O5Label)
   delete fInputTubeMatP2O5Label;
 if (fInputTubeMatP2O5DefLabel)
   delete fInputTubeMatP2O5DefLabel;
 if (fInputTubeMatMnOLabel)
   delete fInputTubeMatMnOLabel;
 if (fInputTubeMatMnODefLabel)
   delete fInputTubeMatMnODefLabel;
 if (fInputTubeMatH2OLabel)
   delete fInputTubeMatH2OLabel;
 if (fInputTubeMatH2ODefLabel)
   delete fInputTubeMatH2ODefLabel;
 
 //LayoutHints 
 if (fLTubeMatFM1Frame)
  delete fLTubeMatFM1Frame;    
 if (fLTubeMatFM2Frame)
  delete fLTubeMatFM2Frame;    
 if (fLTubeMatFM3Frame)
  delete fLTubeMatFM3Frame;      
 if (fLTubeMatFM4Frame)
  delete fLTubeMatFM4Frame;       
 if (fLTubeMatFM5Frame)
  delete fLTubeMatFM5Frame;        
 if (fLTubeMatFM6Frame)
  delete fLTubeMatFM6Frame;      
 if (fLTubeMatFM7Frame)
  delete fLTubeMatFM7Frame;  
 if (fLTubeMatButtonFrame)
  delete fLTubeMatButtonFrame;
 if (fLTubeMatInputName)
  delete fLTubeMatInputName;       
 if (fLTubeMatInputNameDef)
  delete fLTubeMatInputNameDef;    
 if (fLTubeMatInputDensity)
  delete fLTubeMatInputDensity;        
 if (fLTubeMatInputDensityDef)
  delete fLTubeMatInputDensityDef;    
 if (fLTubeMatInputSiO2)
  delete fLTubeMatInputSiO2;        
 if (fLTubeMatInputSiO2Def)
  delete fLTubeMatInputSiO2Def;
 if (fLTubeMatInputAl2O3)
  delete fLTubeMatInputAl2O3;      
 if (fLTubeMatInputAl2O3Def)
  delete fLTubeMatInputAl2O3Def;
 if (fLTubeMatInputFe2O3)
  delete fLTubeMatInputFe2O3;      
 if (fLTubeMatInputFe2O3Def)
  delete fLTubeMatInputFe2O3Def;
 if (fLTubeMatInputFeO)
  delete fLTubeMatInputFeO;      
 if (fLTubeMatInputFeODef)
  delete fLTubeMatInputFeODef;
 if (fLTubeMatInputMgO)
  delete fLTubeMatInputMgO;      
 if (fLTubeMatInputMgODef)
  delete fLTubeMatInputMgODef;
 if (fLTubeMatInputCaO)
  delete fLTubeMatInputCaO;      
 if (fLTubeMatInputCaODef)
  delete fLTubeMatInputCaODef;
 if (fLTubeMatInputNa2O)
  delete fLTubeMatInputNa2O;      
 if (fLTubeMatInputNa2ODef)
  delete fLTubeMatInputNa2ODef;
 if (fLTubeMatInputK2O)
  delete fLTubeMatInputK2O;      
 if (fLTubeMatInputK2ODef)
  delete fLTubeMatInputK2ODef;
 if (fLTubeMatInputTiO2)
  delete fLTubeMatInputTiO2;      
 if (fLTubeMatInputTiO2Def)
  delete fLTubeMatInputTiO2Def;
 if (fLTubeMatInputP2O5)
  delete fLTubeMatInputP2O5;      
 if (fLTubeMatInputP2O5Def)
  delete fLTubeMatInputP2O5Def;
 if (fLTubeMatInputMnO)
  delete fLTubeMatInputMnO;      
 if (fLTubeMatInputMnODef)
  delete fLTubeMatInputMnODef;
 if (fLTubeMatInputH2O)
  delete fLTubeMatInputH2O;      
 if (fLTubeMatInputH2ODef)
  delete fLTubeMatInputH2ODef;
 if (LMatFM1)
   delete LMatFM1;
 if (LMatFM2)
   delete LMatFM2;
 if (LMatFM3)
   delete LMatFM3;
 if (LMatFM4)
   delete LMatFM4;
 if (LMatFM5)
   delete LMatFM5;
 if (LMatFM6)
   delete LMatFM6;
 if (LMatFM7)
   delete LMatFM7;
 if (LMatMacroInputLineName)
   delete LMatMacroInputLineName;
 if (LMatMacroInputLineNameDef)
   delete LMatMacroInputLineNameDef;
 if (LMatMacroInputLineDensity)
   delete LMatMacroInputLineDensity;
 if (LMatMacroInputLineDensityDef)
   delete LMatMacroInputLineDensityDef;
 if (LMatMacroInputLineSiO2)
   delete LMatMacroInputLineSiO2;
 if (LMatMacroInputLineSiO2Def)
   delete LMatMacroInputLineSiO2Def;
 if (LMatMacroInputLineAl2O3)
   delete LMatMacroInputLineAl2O3;
 if (LMatMacroInputLineAl2O3Def)
   delete LMatMacroInputLineAl2O3Def;
 if (LMatMacroInputLineFe2O3)
   delete LMatMacroInputLineFe2O3;
 if (LMatMacroInputLineFe2O3Def)
   delete LMatMacroInputLineFe2O3Def;
 if (LMatMacroInputLineFeO)
   delete LMatMacroInputLineFeO;
 if (LMatMacroInputLineFeODef)
   delete LMatMacroInputLineFeODef;
 if (LMatMacroInputLineMgO)
   delete LMatMacroInputLineMgO;
 if (LMatMacroInputLineMgODef)
   delete LMatMacroInputLineMgODef;
 if (LMatMacroInputLineCaO)
   delete LMatMacroInputLineCaO;
 if (LMatMacroInputLineCaODef)
   delete LMatMacroInputLineCaODef;
 if (LMatMacroInputLineNa2O)
   delete LMatMacroInputLineNa2O;
 if (LMatMacroInputLineNa2ODef)
   delete LMatMacroInputLineNa2ODef;
 if (LMatMacroInputLineK2O)
   delete LMatMacroInputLineK2O;
 if (LMatMacroInputLineK2ODef)
   delete LMatMacroInputLineK2ODef;
 if (LMatMacroInputLineTiO2)
   delete LMatMacroInputLineTiO2;
 if (LMatMacroInputLineTiO2Def)
   delete LMatMacroInputLineTiO2Def;
 if (LMatMacroInputLineP2O5)
   delete LMatMacroInputLineP2O5;
 if (LMatMacroInputLineP2O5Def)
   delete LMatMacroInputLineP2O5Def;
 if (LMatMacroInputLineMnO)
   delete LMatMacroInputLineMnO;
 if (LMatMacroInputLineMnODef)
   delete LMatMacroInputLineMnODef;
 if (LMatMacroInputLineH2O)
   delete LMatMacroInputLineH2O;
 if (LMatMacroInputLineH2ODef)
   delete LMatMacroInputLineH2ODef;
 if (fLInputMatNameLabel)
   delete fLInputMatNameLabel;
 if (fLInputMatNameDefLabel)
   delete fLInputMatNameDefLabel;
 if (fLInputMatDensityLabel)
   delete fLInputMatDensityLabel;
 if (fLInputMatDensityDefLabel)
   delete fLInputMatDensityDefLabel;
 if (fLInputMatSiO2Label)
   delete fLInputMatSiO2Label;
 if (fLInputMatSiO2DefLabel)
   delete fLInputMatSiO2DefLabel;
 if (fLInputMatAl2O3Label)
   delete fLInputMatAl2O3Label;
 if (fLInputMatAl2O3DefLabel)
   delete fLInputMatAl2O3DefLabel;
 if (fLInputMatFe2O3Label)
   delete fLInputMatFe2O3Label;
 if (fLInputMatFe2O3DefLabel)
   delete fLInputMatFe2O3DefLabel;
 if (fLInputMatFeOLabel)
   delete fLInputMatFeOLabel;
 if (fLInputMatFeODefLabel)
   delete fLInputMatFeODefLabel;
 if (fLInputMatMgOLabel)
   delete fLInputMatMgOLabel;
 if (fLInputMatMgODefLabel)
   delete fLInputMatMgODefLabel;
 if (fLInputMatCaOLabel)
   delete fLInputMatCaOLabel;
 if (fLInputMatCaODefLabel)
   delete fLInputMatCaODefLabel;
 if (fLInputMatNa2OLabel)
   delete fLInputMatNa2OLabel;
 if (fLInputMatNa2ODefLabel)
   delete fLInputMatNa2ODefLabel;
 if (fLInputMatK2OLabel)
   delete fLInputMatK2OLabel;
 if (fLInputMatK2ODefLabel)
   delete fLInputMatK2ODefLabel;
 if (fLInputMatTiO2Label)
   delete fLInputMatTiO2Label;
 if (fLInputMatTiO2DefLabel)
   delete fLInputMatTiO2DefLabel;
 if (fLInputMatP2O5Label)
   delete fLInputMatP2O5Label;
 if (fLInputMatP2O5DefLabel)
   delete fLInputMatP2O5DefLabel;
 if (fLInputMatMnOLabel)
   delete fLInputMatMnOLabel;
 if (fLInputMatMnODefLabel)
   delete fLInputMatMnODefLabel;
 if (fLInputMatH2OLabel)
   delete fLInputMatH2OLabel;
 if (fLInputMatH2ODefLabel)
   delete fLInputMatH2ODefLabel;
 if (fButtonpm)
   delete fButtonpm;

 //Frames
 if (fTubeMatFM1Frame)
   delete fTubeMatFM1Frame;
 if (fTubeMatFM2Frame)
   delete fTubeMatFM2Frame;
 if (fTubeMatFM3Frame)
   delete fTubeMatFM3Frame;
 if (fTubeMatFM4Frame)
   delete fTubeMatFM4Frame;
 if (fTubeMatFM5Frame)
   delete fTubeMatFM5Frame;
 if (fTubeMatFM6Frame)
   delete fTubeMatFM6Frame;
 if (fTubeMatFM7Frame)
   delete fTubeMatFM7Frame;
 if (fTubeMatInputNameFrame)
   delete fTubeMatInputNameFrame;
 if (fTubeMatInputNameDefFrame)
   delete fTubeMatInputNameDefFrame;
 if (fTubeMatInputDensityFrame)
   delete fTubeMatInputDensityFrame;
 if (fTubeMatInputDensityDefFrame)
   delete fTubeMatInputDensityDefFrame;
 if (fTubeMatInputSiO2Frame)
   delete fTubeMatInputSiO2Frame;
 if (fTubeMatInputSiO2DefFrame)
   delete fTubeMatInputSiO2DefFrame;
 if (fTubeMatInputAl2O3Frame)
   delete fTubeMatInputAl2O3Frame;
 if (fTubeMatInputAl2O3DefFrame)
   delete fTubeMatInputAl2O3DefFrame;
 if (fTubeMatInputFe2O3Frame)
   delete fTubeMatInputFe2O3Frame;
 if (fTubeMatInputFe2O3DefFrame)
   delete fTubeMatInputFe2O3DefFrame;
 if (fTubeMatInputFeOFrame)
   delete fTubeMatInputFeOFrame;
 if (fTubeMatInputFeODefFrame)
   delete fTubeMatInputFeODefFrame;
 if (fTubeMatInputMgOFrame)
   delete fTubeMatInputMgOFrame;
 if (fTubeMatInputMgODefFrame)
   delete fTubeMatInputMgODefFrame;
 if (fTubeMatInputCaOFrame)
   delete fTubeMatInputCaOFrame;
 if (fTubeMatInputCaODefFrame)
   delete fTubeMatInputCaODefFrame;
 if (fTubeMatInputNa2OFrame)
   delete fTubeMatInputNa2OFrame;
 if (fTubeMatInputNa2ODefFrame)
   delete fTubeMatInputNa2ODefFrame;
 if (fTubeMatInputK2OFrame)
   delete fTubeMatInputK2OFrame;
 if (fTubeMatInputK2ODefFrame)
   delete fTubeMatInputK2ODefFrame;
 if (fTubeMatInputTiO2Frame)
   delete fTubeMatInputTiO2Frame;
 if (fTubeMatInputTiO2DefFrame)
   delete fTubeMatInputTiO2DefFrame;
 if (fTubeMatInputP2O5Frame)
   delete fTubeMatInputP2O5Frame;
 if (fTubeMatInputP2O5DefFrame)
   delete fTubeMatInputP2O5DefFrame;
 if (fTubeMatInputMnOFrame)
   delete fTubeMatInputMnOFrame;
 if (fTubeMatInputMnODefFrame)
   delete fTubeMatInputMnODefFrame;
 if (fTubeMatInputH2OFrame)
   delete fTubeMatInputH2OFrame;
 if (fTubeMatInputH2ODefFrame)
   delete fTubeMatInputH2ODefFrame;
 if (fTubeMatButtonFrame)
   delete fTubeMatButtonFrame;
 
}

void G4TubeMat::CloseWindow()
{
  delete this;
}

void G4TubeMat::OkTubeMat()
{
      TString text1 = "Le nom du materiau composant l'echantillon est : ";
      TString text2 = text1+fInputTubeMatNameEntry->GetText();
      TString text3 = "La masse volumique du materiau composant l'echantillon est de : ";
      TString text4 = text3+fInputTubeMatDensityEntry->GetText()+" g/cm3";
      TString text5 = "La fraction en masse de SiO2 est de : ";
      TString text6 = text5+fInputTubeMatSiO2Entry->GetText();
      TString text7 = "La fraction en masse de Al2O3 est de : ";
      TString text8 = text7+fInputTubeMatAl2O3Entry->GetText();
      TString text9 = "La fraction en masse de Fe2O3 est de : ";
      TString text10 = text9+fInputTubeMatFe2O3Entry->GetText();
      TString text11 = "La fraction en masse de FeO est de : ";
      TString text12 = text11+fInputTubeMatFeOEntry->GetText();
      TString text13 = "La fraction en masse de MgO est de : ";
      TString text14 = text13+fInputTubeMatMgOEntry->GetText();
      TString text15 = "La fraction en masse de CaO est de : ";
      TString text16 = text15+fInputTubeMatCaOEntry->GetText();
      TString text17 = "La fraction en masse de Na2O est de : ";
      TString text18 = text17+fInputTubeMatNa2OEntry->GetText();
      TString text19 = "La fraction en masse de K2O est de : ";
      TString text20 = text19+fInputTubeMatK2OEntry->GetText();
      TString text21 = "La fraction en masse de TiO2 est de : ";
      TString text22 = text21+fInputTubeMatTiO2Entry->GetText();
      TString text23 = "La fraction en masse de P2O5 est de : ";
      TString text24 = text23+fInputTubeMatP2O5Entry->GetText();
      TString text25 = "La fraction en masse de MnO est de : ";
      TString text26 = text25+fInputTubeMatMnOEntry->GetText();
      TString text27 = "La fraction en masse de H2O est de : ";
      TString text28 = text27+fInputTubeMatH2OEntry->GetText();
     
      TString test = text2;
      test += '\n';
      test += text4;
      test += '\n';
      test += text6;
      test += '\n';
      test += text8;
      test += '\n';
      test += text10;
      test += '\n';
      test += text12;
      test += '\n';
      test += text14;
      test += '\n';
      test += text16;
      test += '\n';
      test += text18;
      test += '\n';
      test += text20;
      test += '\n';
      test += text22;
      test += '\n';
      test += text24;
      test += '\n';
      test += text26;
      test += '\n';
      test += text28;
      test += '\n';

      /*tmmacroMenu->GetSourceTextView()->LoadBuffer(test);
	cout<<"LineCount = "<<tmmacroMenu->GetSourceTextView()->ReturnLineCount()<<endl;*/
      //tmmacroMenu->GetSourceTextView()->AddLine(test);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text2);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text4);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text6);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text8);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text10);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text12);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text14);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text16);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text18);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text20);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text22);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text24);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text26);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
      tmmacroMenu->GetSourceTextView()->AddLine(text28);
}


TGCompositeFrame* G4TubeMat::BuildTubeMatFM1Frame(const TGWindow* a)
{
  TGCompositeFrame* MatFM1 = new TGCompositeFrame(a, 100, 100, kHorizontalFrame);
  LMatFM1 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  return MatFM1;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatFM2Frame(const TGWindow* b)
{
  TGCompositeFrame* MatFM2 = new TGCompositeFrame(b, 100, 100, kHorizontalFrame);
  LMatFM2 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  return MatFM2;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatFM3Frame(const TGWindow* c)
{
  TGCompositeFrame* MatFM3 = new TGCompositeFrame(c, 100, 100, kHorizontalFrame);
  LMatFM3 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  return MatFM3;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatFM4Frame(const TGWindow* d)
{
  TGCompositeFrame* MatFM4 = new TGCompositeFrame(d, 100, 100, kHorizontalFrame);
  LMatFM4 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  return MatFM4;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatFM5Frame(const TGWindow* e)
{
  TGCompositeFrame* MatFM5 = new TGCompositeFrame(e, 100, 100, kHorizontalFrame);
  LMatFM5 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  return MatFM5;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatFM6Frame(const TGWindow* f)
{
  TGCompositeFrame* MatFM6 = new TGCompositeFrame(f, 100, 100, kHorizontalFrame);
  LMatFM6 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  return MatFM6;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatFM7Frame(const TGWindow* g)
{
  TGCompositeFrame* MatFM7 = new TGCompositeFrame(g, 100, 100, kHorizontalFrame);
  LMatFM7 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  return MatFM7;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputNameEntry(const TGWindow* h)
{
  TGCompositeFrame *InputLineNameMacro = new TGCompositeFrame(h, 100, 100, kVerticalFrame);

  LMatMacroInputLineName = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatNameEntry = new TGTextEntry(InputLineNameMacro, new TGTextBuffer(10));
  InputLineNameMacro->AddFrame(fInputTubeMatNameEntry, LMatMacroInputLineName);

 fInputTubeMatNameLabel = new TGLabel(InputLineNameMacro, "Nom du materiau");
 fLInputMatNameLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineNameMacro->AddFrame(fInputTubeMatNameLabel,fLInputMatNameLabel);

  return InputLineNameMacro;
  }


TGCompositeFrame* G4TubeMat::BuildTubeMatInputNameDefEntry(const TGWindow* i)
{
  TGCompositeFrame *InputLineNameDefMacro = new TGCompositeFrame(i, 100, 100, kVerticalFrame);

  LMatMacroInputLineNameDef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatNameDefEntry = new TGTextEntry(InputLineNameDefMacro, new TGTextBuffer(10));
  fInputTubeMatNameDefEntry->Insert("Roche");
  InputLineNameDefMacro->AddFrame(fInputTubeMatNameDefEntry, LMatMacroInputLineNameDef);

 fInputTubeMatNameDefLabel = new TGLabel(InputLineNameDefMacro, "Defaut");
 fLInputMatNameDefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineNameDefMacro->AddFrame(fInputTubeMatNameDefLabel,fLInputMatNameDefLabel);

  return InputLineNameDefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputDensityEntry(const TGWindow* j)
{
  TGCompositeFrame *InputLineDensityMacro = new TGCompositeFrame(j, 100, 100, kVerticalFrame);

  LMatMacroInputLineDensity = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatDensityEntry = new TGTextEntry(InputLineDensityMacro, new TGTextBuffer(10));
  InputLineDensityMacro->AddFrame(fInputTubeMatDensityEntry, LMatMacroInputLineDensity);

 fInputTubeMatDensityLabel = new TGLabel(InputLineDensityMacro, "Masse volumique (g/cm3)");
 fLInputMatDensityLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineDensityMacro->AddFrame(fInputTubeMatDensityLabel,fLInputMatDensityLabel);

  return InputLineDensityMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputDensityDefEntry(const TGWindow* k)
{
  TGCompositeFrame *InputLineDensityDefMacro = new TGCompositeFrame(k, 100, 100, kVerticalFrame);

  LMatMacroInputLineDensityDef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatDensityDefEntry = new TGTextEntry(InputLineDensityDefMacro, new TGTextBuffer(10));
  fInputTubeMatDensityDefEntry->Insert("1.640 g/cm3");
  InputLineDensityDefMacro->AddFrame(fInputTubeMatDensityDefEntry, LMatMacroInputLineDensityDef);

 fInputTubeMatDensityDefLabel = new TGLabel(InputLineDensityDefMacro, "Defaut");
 fLInputMatDensityDefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineDensityDefMacro->AddFrame(fInputTubeMatDensityDefLabel,fLInputMatDensityDefLabel);

  return InputLineDensityDefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputSiO2Entry(const TGWindow* l)
{
  TGCompositeFrame *InputLineSiO2Macro = new TGCompositeFrame(l, 100, 100, kVerticalFrame);

  LMatMacroInputLineSiO2 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatSiO2Entry = new TGTextEntry(InputLineSiO2Macro, new TGTextBuffer(10));
  InputLineSiO2Macro->AddFrame(fInputTubeMatSiO2Entry, LMatMacroInputLineSiO2);

 fInputTubeMatSiO2Label = new TGLabel(InputLineSiO2Macro, "Fraction en masse SiO2 (%)");
 fLInputMatSiO2Label = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineSiO2Macro->AddFrame(fInputTubeMatSiO2Label,fLInputMatSiO2Label);

  return InputLineSiO2Macro;
  }


TGCompositeFrame* G4TubeMat::BuildTubeMatInputSiO2DefEntry(const TGWindow* m)
{
  TGCompositeFrame *InputLineSiO2DefMacro = new TGCompositeFrame(m, 100, 100, kVerticalFrame);

  LMatMacroInputLineSiO2Def = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatSiO2DefEntry = new TGTextEntry(InputLineSiO2DefMacro, new TGTextBuffer(10));
  fInputTubeMatSiO2DefEntry->Insert("48.65 %");
  InputLineSiO2DefMacro->AddFrame(fInputTubeMatSiO2DefEntry, LMatMacroInputLineSiO2Def);

 fInputTubeMatSiO2DefLabel = new TGLabel(InputLineSiO2DefMacro, "Defaut");
 fLInputMatSiO2DefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineSiO2DefMacro->AddFrame(fInputTubeMatSiO2DefLabel,fLInputMatSiO2DefLabel);

  return InputLineSiO2DefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputAl2O3Entry(const TGWindow* n)
{
  TGCompositeFrame *InputLineAl2O3Macro = new TGCompositeFrame(n, 100, 100, kVerticalFrame);

  LMatMacroInputLineAl2O3 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatAl2O3Entry = new TGTextEntry(InputLineAl2O3Macro, new TGTextBuffer(10));
  InputLineAl2O3Macro->AddFrame(fInputTubeMatAl2O3Entry, LMatMacroInputLineAl2O3);

 fInputTubeMatAl2O3Label = new TGLabel(InputLineAl2O3Macro, "Fraction en masse Al2O3 (%)");
 fLInputMatAl2O3Label = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineAl2O3Macro->AddFrame(fInputTubeMatAl2O3Label,fLInputMatAl2O3Label);

  return InputLineAl2O3Macro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputAl2O3DefEntry(const TGWindow* o)
{
  TGCompositeFrame *InputLineAl2O3DefMacro = new TGCompositeFrame(o, 100, 100, kVerticalFrame);

  LMatMacroInputLineAl2O3Def = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatAl2O3DefEntry = new TGTextEntry(InputLineAl2O3DefMacro, new TGTextBuffer(10));
  fInputTubeMatAl2O3DefEntry->Insert("14.73 %");
  InputLineAl2O3DefMacro->AddFrame(fInputTubeMatAl2O3DefEntry, LMatMacroInputLineAl2O3Def);

 fInputTubeMatAl2O3DefLabel = new TGLabel(InputLineAl2O3DefMacro, "Defaut");
 fLInputMatAl2O3DefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineAl2O3DefMacro->AddFrame(fInputTubeMatAl2O3DefLabel,fLInputMatAl2O3DefLabel);

  return InputLineAl2O3DefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputFe2O3Entry(const TGWindow* p)
{
  TGCompositeFrame *InputLineFe2O3Macro = new TGCompositeFrame(p, 100, 100, kVerticalFrame);

  LMatMacroInputLineFe2O3 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatFe2O3Entry = new TGTextEntry(InputLineFe2O3Macro, new TGTextBuffer(10));
  InputLineFe2O3Macro->AddFrame(fInputTubeMatFe2O3Entry, LMatMacroInputLineFe2O3);

 fInputTubeMatFe2O3Label = new TGLabel(InputLineFe2O3Macro, "Fraction en masse Fe2O3 (%)");
 fLInputMatFe2O3Label = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineFe2O3Macro->AddFrame(fInputTubeMatFe2O3Label,fLInputMatFe2O3Label);

  return InputLineFe2O3Macro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputFe2O3DefEntry(const TGWindow* q)
{
  TGCompositeFrame *InputLineFe2O3DefMacro = new TGCompositeFrame(q, 100, 100, kVerticalFrame);

  LMatMacroInputLineFe2O3Def = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatFe2O3DefEntry = new TGTextEntry(InputLineFe2O3DefMacro, new TGTextBuffer(10));
  fInputTubeMatFe2O3DefEntry->Insert("2.92 %");
  InputLineFe2O3DefMacro->AddFrame(fInputTubeMatFe2O3DefEntry, LMatMacroInputLineFe2O3Def);

 fInputTubeMatFe2O3DefLabel = new TGLabel(InputLineFe2O3DefMacro, "Defaut");
 fLInputMatFe2O3DefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineFe2O3DefMacro->AddFrame(fInputTubeMatFe2O3DefLabel,fLInputMatFe2O3DefLabel);

  return InputLineFe2O3DefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputFeOEntry(const TGWindow* r)
{
  TGCompositeFrame *InputLineFeOMacro = new TGCompositeFrame(r, 100, 100, kVerticalFrame);

  LMatMacroInputLineFeO = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatFeOEntry = new TGTextEntry(InputLineFeOMacro, new TGTextBuffer(10));
  InputLineFeOMacro->AddFrame(fInputTubeMatFeOEntry, LMatMacroInputLineFeO);

 fInputTubeMatFeOLabel = new TGLabel(InputLineFeOMacro, "Fraction en masse FeO (%)");
 fLInputMatFeOLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineFeOMacro->AddFrame(fInputTubeMatFeOLabel,fLInputMatFeOLabel);

  return InputLineFeOMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputFeODefEntry(const TGWindow* s)
{
  TGCompositeFrame *InputLineFeODefMacro = new TGCompositeFrame(s, 100, 100, kVerticalFrame);

  LMatMacroInputLineFeODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatFeODefEntry = new TGTextEntry(InputLineFeODefMacro, new TGTextBuffer(10));
  fInputTubeMatFeODefEntry->Insert("7.51 %");
  InputLineFeODefMacro->AddFrame(fInputTubeMatFeODefEntry, LMatMacroInputLineFeODef);

 fInputTubeMatFeODefLabel = new TGLabel(InputLineFeODefMacro, "Defaut");
 fLInputMatFeODefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineFeODefMacro->AddFrame(fInputTubeMatFeODefLabel,fLInputMatFeODefLabel);

  return InputLineFeODefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputMgOEntry(const TGWindow* t)
{
  TGCompositeFrame *InputLineMgOMacro = new TGCompositeFrame(t, 100, 100, kVerticalFrame);

  LMatMacroInputLineMgO = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatMgOEntry = new TGTextEntry(InputLineMgOMacro, new TGTextBuffer(10));
  InputLineMgOMacro->AddFrame(fInputTubeMatMgOEntry, LMatMacroInputLineMgO);

 fInputTubeMatMgOLabel = new TGLabel(InputLineMgOMacro, "Fraction en masse MgO (%)");
 fLInputMatMgOLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineMgOMacro->AddFrame(fInputTubeMatMgOLabel,fLInputMatMgOLabel);

  return InputLineMgOMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputMgODefEntry(const TGWindow* u)
{
  TGCompositeFrame *InputLineMgODefMacro = new TGCompositeFrame(u, 100, 100, kVerticalFrame);

  LMatMacroInputLineMgODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatMgODefEntry = new TGTextEntry(InputLineMgODefMacro, new TGTextBuffer(10));
  fInputTubeMatMgODefEntry->Insert("10.3 %");
  InputLineMgODefMacro->AddFrame(fInputTubeMatMgODefEntry, LMatMacroInputLineMgODef);

 fInputTubeMatMgODefLabel = new TGLabel(InputLineMgODefMacro, "Defaut");
 fLInputMatMgODefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineMgODefMacro->AddFrame(fInputTubeMatMgODefLabel,fLInputMatMgODefLabel);

  return InputLineMgODefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputCaOEntry(const TGWindow* v)
{
  TGCompositeFrame *InputLineCaOMacro = new TGCompositeFrame(v, 100, 100, kVerticalFrame);

  LMatMacroInputLineCaO = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatCaOEntry = new TGTextEntry(InputLineCaOMacro, new TGTextBuffer(10));
  InputLineCaOMacro->AddFrame(fInputTubeMatCaOEntry, LMatMacroInputLineCaO);

 fInputTubeMatCaOLabel = new TGLabel(InputLineCaOMacro, "Fraction en masse CaO (%)");
 fLInputMatCaOLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineCaOMacro->AddFrame(fInputTubeMatCaOLabel,fLInputMatCaOLabel);

  return InputLineCaOMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputCaODefEntry(const TGWindow* w)
{
  TGCompositeFrame *InputLineCaODefMacro = new TGCompositeFrame(w, 100, 100, kVerticalFrame);

  LMatMacroInputLineCaODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatCaODefEntry = new TGTextEntry(InputLineCaODefMacro, new TGTextBuffer(10));
  fInputTubeMatCaODefEntry->Insert("9.55 %");
  InputLineCaODefMacro->AddFrame(fInputTubeMatCaODefEntry, LMatMacroInputLineCaODef);

 fInputTubeMatCaODefLabel = new TGLabel(InputLineCaODefMacro, "Defaut");
 fLInputMatCaODefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineCaODefMacro->AddFrame(fInputTubeMatCaODefLabel,fLInputMatCaODefLabel);

  return InputLineCaODefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputNa2OEntry(const TGWindow* x)
{
  TGCompositeFrame *InputLineNa2OMacro = new TGCompositeFrame(x, 100, 100, kVerticalFrame);

  LMatMacroInputLineNa2O = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatNa2OEntry = new TGTextEntry(InputLineNa2OMacro, new TGTextBuffer(10));
  InputLineNa2OMacro->AddFrame(fInputTubeMatNa2OEntry, LMatMacroInputLineNa2O);

 fInputTubeMatNa2OLabel = new TGLabel(InputLineNa2OMacro, "Fraction en masse Na2O (%)");
 fLInputMatNa2OLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineNa2OMacro->AddFrame(fInputTubeMatNa2OLabel,fLInputMatNa2OLabel);

  return InputLineNa2OMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputNa2ODefEntry(const TGWindow* y)
{
  TGCompositeFrame *InputLineNa2ODefMacro = new TGCompositeFrame(y, 100, 100, kVerticalFrame);

  LMatMacroInputLineNa2ODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatNa2ODefEntry = new TGTextEntry(InputLineNa2ODefMacro, new TGTextBuffer(10));
  fInputTubeMatNa2ODefEntry->Insert("3.62 %");
  InputLineNa2ODefMacro->AddFrame(fInputTubeMatNa2ODefEntry, LMatMacroInputLineNa2ODef);

 fInputTubeMatNa2ODefLabel = new TGLabel(InputLineNa2ODefMacro, "Defaut");
 fLInputMatNa2ODefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineNa2ODefMacro->AddFrame(fInputTubeMatNa2ODefLabel,fLInputMatNa2ODefLabel);

  return InputLineNa2ODefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputK2OEntry(const TGWindow* z)
{
  TGCompositeFrame *InputLineK2OMacro = new TGCompositeFrame(z, 100, 100, kVerticalFrame);

  LMatMacroInputLineK2O = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatK2OEntry = new TGTextEntry(InputLineK2OMacro, new TGTextBuffer(10));
  InputLineK2OMacro->AddFrame(fInputTubeMatK2OEntry, LMatMacroInputLineK2O);

 fInputTubeMatK2OLabel = new TGLabel(InputLineK2OMacro, "Fraction en masse K2O (%)");
 fLInputMatK2OLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineK2OMacro->AddFrame(fInputTubeMatK2OLabel,fLInputMatK2OLabel);

  return InputLineK2OMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputK2ODefEntry(const TGWindow* aa)
{
  TGCompositeFrame *InputLineK2ODefMacro = new TGCompositeFrame(aa, 100, 100, kVerticalFrame);

  LMatMacroInputLineK2ODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatK2ODefEntry = new TGTextEntry(InputLineK2ODefMacro, new TGTextBuffer(10));
  fInputTubeMatK2ODefEntry->Insert("0.7 %");
  InputLineK2ODefMacro->AddFrame(fInputTubeMatK2ODefEntry, LMatMacroInputLineK2ODef);

 fInputTubeMatK2ODefLabel = new TGLabel(InputLineK2ODefMacro, "Defaut");
 fLInputMatK2ODefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineK2ODefMacro->AddFrame(fInputTubeMatK2ODefLabel,fLInputMatK2ODefLabel);

  return InputLineK2ODefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputTiO2Entry(const TGWindow* bb)
{
  TGCompositeFrame *InputLineTiO2Macro = new TGCompositeFrame(bb, 100, 100, kVerticalFrame);

  LMatMacroInputLineTiO2 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatTiO2Entry = new TGTextEntry(InputLineTiO2Macro, new TGTextBuffer(10));
  InputLineTiO2Macro->AddFrame(fInputTubeMatTiO2Entry, LMatMacroInputLineTiO2);

 fInputTubeMatTiO2Label = new TGLabel(InputLineTiO2Macro, "Fraction en masse TiO2 (%)");
 fLInputMatTiO2Label = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineTiO2Macro->AddFrame(fInputTubeMatTiO2Label,fLInputMatTiO2Label);

  return InputLineTiO2Macro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputTiO2DefEntry(const TGWindow* cc)
{
  TGCompositeFrame *InputLineTiO2DefMacro = new TGCompositeFrame(cc, 100, 100, kVerticalFrame);

  LMatMacroInputLineTiO2Def = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatTiO2DefEntry = new TGTextEntry(InputLineTiO2DefMacro, new TGTextBuffer(10));
  fInputTubeMatTiO2DefEntry->Insert("1.55 %");
  InputLineTiO2DefMacro->AddFrame(fInputTubeMatTiO2DefEntry, LMatMacroInputLineTiO2Def);

 fInputTubeMatTiO2DefLabel = new TGLabel(InputLineTiO2DefMacro, "Defaut");
 fLInputMatTiO2DefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineTiO2DefMacro->AddFrame(fInputTubeMatTiO2DefLabel,fLInputMatTiO2DefLabel);

  return InputLineTiO2DefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputP2O5Entry(const TGWindow* dd)
{
  TGCompositeFrame *InputLineP2O5Macro = new TGCompositeFrame(dd, 100, 100, kVerticalFrame);

  LMatMacroInputLineP2O5 = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatP2O5Entry = new TGTextEntry(InputLineP2O5Macro, new TGTextBuffer(10));
  InputLineP2O5Macro->AddFrame(fInputTubeMatP2O5Entry, LMatMacroInputLineP2O5);

 fInputTubeMatP2O5Label = new TGLabel(InputLineP2O5Macro, "Fraction en masse P2O5 (%)");
 fLInputMatP2O5Label = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineP2O5Macro->AddFrame(fInputTubeMatP2O5Label,fLInputMatP2O5Label);

  return InputLineP2O5Macro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputP2O5DefEntry(const TGWindow* ee)
{
  TGCompositeFrame *InputLineP2O5DefMacro = new TGCompositeFrame(ee, 100, 100, kVerticalFrame);

  LMatMacroInputLineP2O5Def = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatP2O5DefEntry = new TGTextEntry(InputLineP2O5DefMacro, new TGTextBuffer(10));
  fInputTubeMatP2O5DefEntry->Insert("0.39 %");
  InputLineP2O5DefMacro->AddFrame(fInputTubeMatP2O5DefEntry, LMatMacroInputLineP2O5Def);

 fInputTubeMatP2O5DefLabel = new TGLabel(InputLineP2O5DefMacro, "Defaut");
 fLInputMatP2O5DefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineP2O5DefMacro->AddFrame(fInputTubeMatP2O5DefLabel,fLInputMatP2O5DefLabel);

  return InputLineP2O5DefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputMnOEntry(const TGWindow* ff)
{
  TGCompositeFrame *InputLineMnOMacro = new TGCompositeFrame(ff, 100, 100, kVerticalFrame);

  LMatMacroInputLineMnO = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatMnOEntry = new TGTextEntry(InputLineMnOMacro, new TGTextBuffer(10));
  InputLineMnOMacro->AddFrame(fInputTubeMatMnOEntry, LMatMacroInputLineMnO);

  fInputTubeMatMnOLabel = new TGLabel(InputLineMnOMacro, "Fraction en masse MnO (%)");
 fLInputMatMnOLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
 InputLineMnOMacro->AddFrame(fInputTubeMatMnOLabel,fLInputMatMnOLabel);

  return InputLineMnOMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputMnODefEntry(const TGWindow* gg)
{
  TGCompositeFrame *InputLineMnODefMacro = new TGCompositeFrame(gg, 100, 100, kVerticalFrame);

  LMatMacroInputLineMnODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatMnODefEntry = new TGTextEntry(InputLineMnODefMacro, new TGTextBuffer(10));
  fInputTubeMatMnODefEntry->Insert("0.16 %");
  InputLineMnODefMacro->AddFrame(fInputTubeMatMnODefEntry, LMatMacroInputLineMnODef);

 fInputTubeMatMnODefLabel = new TGLabel(InputLineMnODefMacro, "Defaut");
 fLInputMatMnODefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineMnODefMacro->AddFrame(fInputTubeMatMnODefLabel,fLInputMatMnODefLabel);

  return InputLineMnODefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputH2OEntry(const TGWindow* hh)
{
  TGCompositeFrame *InputLineH2OMacro = new TGCompositeFrame(hh, 100, 100, kVerticalFrame);

  LMatMacroInputLineH2O = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatH2OEntry = new TGTextEntry(InputLineH2OMacro, new TGTextBuffer(10));
  InputLineH2OMacro->AddFrame(fInputTubeMatH2OEntry, LMatMacroInputLineH2O);

 fInputTubeMatH2OLabel = new TGLabel(InputLineH2OMacro, "Fraction en masse H2O (%)");
 fLInputMatH2OLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineH2OMacro->AddFrame(fInputTubeMatH2OLabel,fLInputMatH2OLabel);

  return InputLineH2OMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatInputH2ODefEntry(const TGWindow* ii)
{
  TGCompositeFrame *InputLineH2ODefMacro = new TGCompositeFrame(ii, 100, 100, kVerticalFrame);

  LMatMacroInputLineH2ODef = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);

  fInputTubeMatH2ODefEntry = new TGTextEntry(InputLineH2ODefMacro, new TGTextBuffer(10));
  fInputTubeMatH2ODefEntry->Insert("0.22 %");
  InputLineH2ODefMacro->AddFrame(fInputTubeMatH2ODefEntry, LMatMacroInputLineH2ODef);

 fInputTubeMatH2ODefLabel = new TGLabel(InputLineH2ODefMacro, "Defaut");
 fLInputMatH2ODefLabel = new TGLayoutHints(kLHintsCenterX | kLHintsCenterY | kLHintsBottom | kLHintsTop, 2, 2, 2, 2);
  InputLineH2ODefMacro->AddFrame(fInputTubeMatH2ODefLabel,fLInputMatH2ODefLabel);

  return InputLineH2ODefMacro;
}


TGCompositeFrame* G4TubeMat::BuildTubeMatButtonFrame(const TGWindow* p)
{
  TGCompositeFrame *buttonpm = new TGCompositeFrame(p, 100, 100, kHorizontalFrame);
  fButtonpm = new TGLayoutHints(kLHintsBottom | kLHintsLeft, 2, 2, 2, 2);

  fOkTubeMatButton = new TGTextButton(buttonpm, "&Ok", kM_OK_TUBEMAT);
  fOkTubeMatButton->Associate(this);
  fOkTubeMatButton->SetToolTipText("Choix du materiau de l'echantillon");
  fOkTubeMatButton->Connect("Clicked()", "G4TubeMat", this, "OkTubeMat()");
  buttonpm->AddFrame(fOkTubeMatButton, fButtonpm);

  fClearAllTubeMatButton = new TGTextButton(buttonpm, "&ClearALL", kM_CLEARALL_TUBEMAT);
  fClearAllTubeMatButton->Associate(this);
  fClearAllTubeMatButton->SetToolTipText("Clear All Entry Line");
  fClearAllTubeMatButton->Connect("Clicked()", "G4TubeMat", this, "ClearAllTubeMat()"); 
  buttonpm->AddFrame(fClearAllTubeMatButton, fButtonpm);

  fExitTubeMatButton = new TGTextButton(buttonpm, "&Exit", kM_EXIT_TUBEMAT);
  fExitTubeMatButton->Associate(this);
  fExitTubeMatButton->SetToolTipText("Close TubeMat Window");
  buttonpm->AddFrame(fExitTubeMatButton, fButtonpm);
  fExitTubeMatButton->Connect("Clicked()", "G4TubeMat", this, "SendCloseMessage()"); 


  return buttonpm;

}

void G4TubeMat::ClearAllTubeMat()
{
  fInputTubeMatNameEntry->Clear();
  fInputTubeMatDensityEntry->Clear();
  fInputTubeMatSiO2Entry->Clear();
  fInputTubeMatAl2O3Entry->Clear();
  fInputTubeMatFe2O3Entry->Clear();
  fInputTubeMatFeOEntry->Clear();
  fInputTubeMatMgOEntry->Clear();
  fInputTubeMatCaOEntry->Clear();
  fInputTubeMatNa2OEntry->Clear();
  fInputTubeMatK2OEntry->Clear();
  fInputTubeMatTiO2Entry->Clear();
  fInputTubeMatP2O5Entry->Clear();
  fInputTubeMatMnOEntry->Clear();
  fInputTubeMatH2OEntry->Clear();
}

Double_t G4TubeMat::OCalc(Double_t v1, Double_t v2, Double_t v3, Double_t v4, Double_t v5, Double_t v6, Double_t v7, Double_t v8, Double_t v9, Double_t v10, Double_t v11, Double_t v12) 
{
  return (2*A_O*v1/(A_Si+2*A_O) + 3*A_O*v2/(3*A_O+2*A_Al) + 3*A_O*v3/(3*A_O+2*A_Fe) + A_O*v4/(A_O+A_Fe) + A_O*v5/(A_O+A_Mg) + A_O*v6/(A_O+A_Ca) + A_O*v7/(A_O+2*A_Na) + A_O*v8/(A_O+2*A_K) + 2*A_O*v9/(2*A_O+A_Ti) + 5*A_O*v10/(5*A_O+2*A_P) + A_O*v11/(A_O+A_Mn) + A_O*v12/(A_O+2*A_H));
}

Double_t G4TubeMat::HCalc(Double_t v1) 
{
  return (2*A_H*v1/(A_O+2*A_H));
}

Double_t G4TubeMat::AlCalc(Double_t v1) 
{
  return (2*A_Al*v1/(3*A_O+2*A_Al));
}

Double_t G4TubeMat::SiCalc(Double_t v1) 
{
  return (A_Si*v1/(A_Si+2*A_O));
}

Double_t G4TubeMat::MgCalc(Double_t v1) 
{
  return (A_Mg*v1/(A_O+A_Mg));
}

Double_t G4TubeMat::PCalc(Double_t v1) 
{
  return (2*A_P*v1/(5*A_O+2*A_P));
}

Double_t G4TubeMat::TiCalc(Double_t v1) 
{
  return (A_Ti*v1/(A_Ti+2*A_O));
}

Double_t G4TubeMat::KCalc(Double_t v1) 
{
  return (2*A_K*v1/(A_O+2*A_K));
}

Double_t G4TubeMat::NaCalc(Double_t v1) 
{
  return (2*A_Na*v1/(A_O+2*A_Na));
}

Double_t G4TubeMat::CaCalc(Double_t v1) 
{
  return (A_Ca*v1/(A_O+A_Ca));
}

Double_t G4TubeMat::MnCalc(Double_t v1) 
{
  return (A_Mn*v1/(A_O+A_Mn));
}

Double_t G4TubeMat::FeCalc(Double_t v1, Double_t v2) 
{
  return (2*A_Fe*v1/(3*A_O+2*A_Fe) + A_Fe*v2/(A_Fe+A_O));
}

ClassImpQ(G4TubeMat)
